@@ -1586,9 +1586,11 @@ int leon_prom_amba_init(unsigned int a, unsigned int b, unsigned int f, int id,
 			/* DBG_PRINTF_2("Found mpirq 0x%x cpus\n",j); */
 #endif
 		}
+#if 0 /* Linux clears IRQ controller in newer kernels, besides must clear only for booting cpu. */
 		/* quite irq */
 		if (regs)
 			BYPASS_STORE_PA(&regs->mask[0], 0);
+#endif
 
 	} else if (typ == APB_SLAVE &&
 		   vendor == VENDOR_GAISLER && device == GAISLER_APBUART) {
@@ -1654,6 +1656,7 @@ int __attribute__ ((__section__(".img.main.text"))) __main(void)
 {
 
 	char *c;
+	unsigned long long *l;
 	int nextid = 0;
 	struct find_data f;
 	void (*kernel) (struct linux_romvec *);
@@ -1686,8 +1689,20 @@ int __attribute__ ((__section__(".img.main.text"))) __main(void)
 	/*set_cache(0); */
 
 	if (id == 0) {
-		/* clear bss */
-		c = (char *)&bss_start;
+		/* clear bss using std when possible, bss may end on byte
+		 * boundary
+		 */
+		l = (unsigned long long *)&bss_start;
+#if 0 /* Temporary removed because of space needed */
+		if (((unsigned int)l & 0x7) == 0) {
+			while (l < (void *)((unsigned int)&bss_end & ~0x7)) {
+				*l = 0;
+				l++;
+			}
+		}
+#endif
+		/* clear last bytes */
+		c = (char *)l;
 		while (c < (char *)&bss_end) {
 			*c = (char)0;
 			c++;
